==> pipewire-docs-1:1.4.9-2-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/search/defines_3.js <==
var searchData=
[
  ['spa_5falignof_0',['SPA_ALIGNOF',['../defs_8h.html#a945ae1c618821a3f8e55acb78ba7a2b1',1,'defs.h']]],
  ['spa_5fapi_5fbuffer_1',['SPA_API_BUFFER',['../buffer_2buffer_8h.html#af3acbfbdd2ebf053eca8b9311db9725e',1,'buffer.h']]],
  ['spa_5fapi_5fbuffer_5falloc_2',['SPA_API_BUFFER_ALLOC',['../alloc_8h.html#a61a2d0b5f20d6024a34dc6ab4c90e7a3',1,'alloc.h']]],
  ['spa_5fapi_5fcontrol_5fump_5futils_3',['SPA_API_CONTROL_UMP_UTILS',['../ump-utils_8h.html#aab91d79d1e1f78b92669f48eefdb5986',1,'ump-utils.h']]],
  ['spa_5fapi_5fcpu_4',['SPA_API_CPU',['../cpu_8h.html#a83f386f154bfbe320429e9ed83c407ab',1,'cpu.h']]],
  ['spa_5fapi_5fdbus_5',['SPA_API_DBUS',['../dbus_8h.html#a17b4d97eee972e77a2d8b52e93713736',1,'dbus.h']]],
  ['spa_5fapi_5fdebug_5flog_6',['SPA_API_DEBUG_LOG',['../spa_2include_2spa_2debug_2log_8h.html#a7d8969287153fb839f25daede66319ed',1,'log.h']]],
  ['spa_5fapi_5fdevice_7',['SPA_API_DEVICE',['../spa_2include_2spa_2monitor_2device_8h.html#aef6f26803d6169e78bcfb0546e7baaaa',1,'device.h']]],
  ['spa_5fapi_5fdevice_5futils_8',['SPA_API_DEVICE_UTILS',['../spa_2include_2spa_2monitor_2utils_8h.html#a886afc8b410e2b6b8cc395112fe21a84',1,'utils.h']]],
  ['spa_5fapi_5fdict_9',['SPA_API_DICT',['../utils_2dict_8h.html#a4151955018dc36ce693ce41e1fe80f63',1,'dict.h']]],
  ['spa_5fapi_5ffilter_5fgraph_10',['SPA_API_FILTER_GRAPH',['../filter-graph_8h.html#aadc90c5bc586c6be9d05c406007a9d98',1,'filter-graph.h']]],
  ['spa_5fapi_5fhook_11',['SPA_API_HOOK',['../hook_8h.html#a65394ffa003b1e5709c2922d2ffe5616',1,'hook.h']]],
  ['spa_5fapi_5fi18n_12',['SPA_API_I18N',['../spa_2include_2spa_2support_2i18n_8h.html#a9ba71a2e26ccccd19dd6dfbebdd05811',1,'i18n.h']]],
  ['spa_5fapi_5fjson_13',['SPA_API_JSON',['../json-core_8h.html#a65048925f8192b16939ff90ffd4e00ac',1,'json-core.h']]],
  ['spa_5fapi_5fjson_5fpod_14',['SPA_API_JSON_POD',['../json-pod_8h.html#aa7e6a4e1d92a73dbbaf2aeb6532299c4',1,'json-pod.h']]],
  ['spa_5fapi_5fjson_5futils_15',['SPA_API_JSON_UTILS',['../json_8h.html#a59f3a5490ce75d7901c368163d9a01ef',1,'json.h']]],
  ['spa_5fapi_5flist_16',['SPA_API_LIST',['../list_8h.html#a69067358690d6e5427e13af5dd8fe60b',1,'list.h']]],
  ['spa_5fapi_5flog_17',['SPA_API_LOG',['../spa_2include_2spa_2support_2log_8h.html#aa7bfa6cd4211a17dc1ffab672480148a',1,'log.h']]],
  ['spa_5fapi_5floop_18',['SPA_API_LOOP',['../spa_2include_2spa_2support_2loop_8h.html#a316f65a41a8d3503dd5fea32a953a076',1,'loop.h']]],
  ['spa_5fapi_5fmeta_19',['SPA_API_META',['../meta_8h.html#a1de7a7d4e82818b4d69559c076088f5e',1,'meta.h']]],
  ['spa_5fapi_5fplugin_20',['SPA_API_PLUGIN',['../plugin_8h.html#ad3a09846bfe4f70b2fe401547e510e81',1,'plugin.h']]],
  ['spa_5fapi_5fplugin_5floader_21',['SPA_API_PLUGIN_LOADER',['../plugin-loader_8h.html#a3a08799d32edd08129bedf983942af28',1,'plugin-loader.h']]],
  ['spa_5fapi_5fpod_5fcompare_22',['SPA_API_POD_COMPARE',['../compare_8h.html#ae43530d3891e4ac548d62f1e1377cb91',1,'compare.h']]],
  ['spa_5fapi_5fpod_5ffilter_23',['SPA_API_POD_FILTER',['../spa_2include_2spa_2pod_2filter_8h.html#a2de0ad82ebab03e77eeb282154d355d1',1,'filter.h']]],
  ['spa_5fapi_5fpod_5fiter_24',['SPA_API_POD_ITER',['../iter_8h.html#a8d29d2c83392e0d442854c113b06c0a0',1,'iter.h']]],
  ['spa_5fapi_5fpod_5fparser_25',['SPA_API_POD_PARSER',['../parser_8h.html#a14fff36be3bd52e6c2605d341fc4593b',1,'parser.h']]],
  ['spa_5fapi_5fstring_26',['SPA_API_STRING',['../string_8h.html#ad7bfe1db64cc55ee2cea6d8defd41ad1',1,'string.h']]],
  ['spa_5fapi_5fsystem_27',['SPA_API_SYSTEM',['../system_8h.html#ac93dac564884228976207ed0a75792f8',1,'system.h']]],
  ['spa_5fapi_5fthread_28',['SPA_API_THREAD',['../spa_2include_2spa_2support_2thread_8h.html#ade1e7f421ad3a09c17a838eee8ddaf86',1,'thread.h']]],
  ['spa_5fapi_5ftype_29',['SPA_API_TYPE',['../spa_2include_2spa_2utils_2type_8h.html#af98c7db2c0cc5894f941ab749d3c4a6d',1,'type.h']]],
  ['spa_5fconcat_30',['SPA_CONCAT',['../defs_8h.html#ae8d04dcfc40049c1dea436f20abddab9',1,'defs.h']]],
  ['spa_5fconcat_5fnoexpand_31',['SPA_CONCAT_NOEXPAND',['../defs_8h.html#a27da3911c40a5196c564a9167e69d35d',1,'defs.h']]],
  ['spa_5fstatic_5fassert_32',['SPA_STATIC_ASSERT',['../defs_8h.html#a65b5e16e8238d0737866b059b57fdfc8',1,'defs.h']]],
  ['spa_5fstatic_5fassert_5fimpl_33',['SPA_STATIC_ASSERT_IMPL',['../defs_8h.html#ad3dec379e71d18eb2fee2e75dfee291e',1,'defs.h']]]
];

==> pipewire-docs-1:1.6.0-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/search/defines_3.js <==
var searchData=
[
  ['spa_5falignof_0',['SPA_ALIGNOF',['../defs_8h.html#a945ae1c618821a3f8e55acb78ba7a2b1',1,'defs.h']]],
  ['spa_5fapi_5fbuffer_1',['SPA_API_BUFFER',['../buffer_2buffer_8h.html#af3acbfbdd2ebf053eca8b9311db9725e',1,'buffer.h']]],
  ['spa_5fapi_5fbuffer_5falloc_2',['SPA_API_BUFFER_ALLOC',['../alloc_8h.html#a61a2d0b5f20d6024a34dc6ab4c90e7a3',1,'alloc.h']]],
  ['spa_5fapi_5fcontrol_5fump_5futils_3',['SPA_API_CONTROL_UMP_UTILS',['../ump-utils_8h.html#aab91d79d1e1f78b92669f48eefdb5986',1,'ump-utils.h']]],
  ['spa_5fapi_5fcpu_4',['SPA_API_CPU',['../cpu_8h.html#a83f386f154bfbe320429e9ed83c407ab',1,'cpu.h']]],
  ['spa_5fapi_5fdbus_5',['SPA_API_DBUS',['../dbus_8h.html#a17b4d97eee972e77a2d8b52e93713736',1,'dbus.h']]],
  ['spa_5fapi_5fdebug_5flog_6',['SPA_API_DEBUG_LOG',['../spa_2include_2spa_2debug_2log_8h.html#a7d8969287153fb839f25daede66319ed',1,'log.h']]],
  ['spa_5fapi_5fdevice_7',['SPA_API_DEVICE',['../spa_2include_2spa_2monitor_2device_8h.html#aef6f26803d6169e78bcfb0546e7baaaa',1,'device.h']]],
  ['spa_5fapi_5fdevice_5futils_8',['SPA_API_DEVICE_UTILS',['../spa_2include_2spa_2monitor_2utils_8h.html#a886afc8b410e2b6b8cc395112fe21a84',1,'utils.h']]],
  ['spa_5fapi_5fdict_9',['SPA_API_DICT',['../utils_2dict_8h.html#a4151955018dc36ce693ce41e1fe80f63',1,'dict.h']]],
  ['spa_5fapi_5ffilter_5fgraph_10',['SPA_API_FILTER_GRAPH',['../filter-graph_8h.html#aadc90c5bc586c6be9d05c406007a9d98',1,'filter-graph.h']]],
  ['spa_5fapi_5fhook_11',['SPA_API_HOOK',['../hook_8h.html#a65394ffa003b1e5709c2922d2ffe5616',1,'hook.h']]],
  ['spa_5fapi_5fi18n_12',['SPA_API_I18N',['../spa_2include_2spa_2support_2i18n_8h.html#a9ba71a2e26ccccd19dd6dfbebdd05811',1,'i18n.h']]],
  ['spa_5fapi_5fjson_13',['SPA_API_JSON',['../json-core_8h.html#a65048925f8192b16939ff90ffd4e00ac',1,'json-core.h']]],
  ['spa_5fapi_5fjson_5fpod_14',['SPA_API_JSON_POD',['../json-pod_8h.html#aa7e6a4e1d92a73dbbaf2aeb6532299c4',1,'json-pod.h']]],
  ['spa_5fapi_5fjson_5futils_15',['SPA_API_JSON_UTILS',['../json_8h.html#a59f3a5490ce75d7901c368163d9a01ef',1,'json.h']]],
  ['spa_5fapi_5flist_16',['SPA_API_LIST',['../list_8h.html#a69067358690d6e5427e13af5dd8fe60b',1,'list.h']]],
  ['spa_5fapi_5flog_17',['SPA_API_LOG',['../spa_2include_2spa_2support_2log_8h.html#aa7bfa6cd4211a17dc1ffab672480148a',1,'log.h']]],
  ['spa_5fapi_5floop_18',['SPA_API_LOOP',['../spa_2include_2spa_2support_2loop_8h.html#a316f65a41a8d3503dd5fea32a953a076',1,'loop.h']]],
  ['spa_5fapi_5fmeta_19',['SPA_API_META',['../meta_8h.html#a1de7a7d4e82818b4d69559c076088f5e',1,'meta.h']]],
  ['spa_5fapi_5fplugin_20',['SPA_API_PLUGIN',['../plugin_8h.html#ad3a09846bfe4f70b2fe401547e510e81',1,'plugin.h']]],
  ['spa_5fapi_5fplugin_5floader_21',['SPA_API_PLUGIN_LOADER',['../plugin-loader_8h.html#a3a08799d32edd08129bedf983942af28',1,'plugin-loader.h']]],
  ['spa_5fapi_5fpod_5fbody_22',['SPA_API_POD_BODY',['../body_8h.html#a8e9a6a6e6e79a2889d793c877d3edff2',1,'body.h']]],
  ['spa_5fapi_5fpod_5fcompare_23',['SPA_API_POD_COMPARE',['../compare_8h.html#ae43530d3891e4ac548d62f1e1377cb91',1,'compare.h']]],
  ['spa_5fapi_5fpod_5ffilter_24',['SPA_API_POD_FILTER',['../spa_2include_2spa_2pod_2filter_8h.html#a2de0ad82ebab03e77eeb282154d355d1',1,'filter.h']]],
  ['spa_5fapi_5fpod_5fiter_25',['SPA_API_POD_ITER',['../iter_8h.html#a8d29d2c83392e0d442854c113b06c0a0',1,'iter.h']]],
  ['spa_5fapi_5fpod_5fparser_26',['SPA_API_POD_PARSER',['../parser_8h.html#a14fff36be3bd52e6c2605d341fc4593b',1,'parser.h']]],
  ['spa_5fapi_5fpod_5fsimplify_27',['SPA_API_POD_SIMPLIFY',['../simplify_8h.html#a758e7ff701fe554ec1862c2e7c50836b',1,'simplify.h']]],
  ['spa_5fapi_5fstring_28',['SPA_API_STRING',['../string_8h.html#ad7bfe1db64cc55ee2cea6d8defd41ad1',1,'string.h']]],
  ['spa_5fapi_5fsystem_29',['SPA_API_SYSTEM',['../system_8h.html#ac93dac564884228976207ed0a75792f8',1,'system.h']]],
  ['spa_5fapi_5fthread_30',['SPA_API_THREAD',['../spa_2include_2spa_2support_2thread_8h.html#ade1e7f421ad3a09c17a838eee8ddaf86',1,'thread.h']]],
  ['spa_5fapi_5ftype_31',['SPA_API_TYPE',['../spa_2include_2spa_2utils_2type_8h.html#af98c7db2c0cc5894f941ab749d3c4a6d',1,'type.h']]],
  ['spa_5fconcat_32',['SPA_CONCAT',['../defs_8h.html#ae8d04dcfc40049c1dea436f20abddab9',1,'defs.h']]],
  ['spa_5fconcat_5fnoexpand_33',['SPA_CONCAT_NOEXPAND',['../defs_8h.html#a27da3911c40a5196c564a9167e69d35d',1,'defs.h']]],
  ['spa_5fstatic_5fassert_34',['SPA_STATIC_ASSERT',['../defs_8h.html#a65b5e16e8238d0737866b059b57fdfc8',1,'defs.h']]],
  ['spa_5fstatic_5fassert_5fimpl_35',['SPA_STATIC_ASSERT_IMPL',['../defs_8h.html#ad3dec379e71d18eb2fee2e75dfee291e',1,'defs.h']]]
];
